@@ -5,7 +5,7 @@
    callbackBuffer : This file is part of pstoedit
    streambuf that writes the data to a user defineable call back function
 
-   Copyright (C) 1998 - 2013 Wolfgang Glunz, wglunz35_AT_pstoedit.net
+   Copyright (C) 1998 - 2018 Wolfgang Glunz, wglunz35_AT_pstoedit.net
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -40,7 +40,7 @@ The GNU C++ Iostream Library
 #include I_streamb
 USESTD
 
-#if !defined(HAVESTL) && !defined(__GNUG__)
+#if !defined(HAVE_STL) && !defined(__GNUG__)
 // this should be defined for all ANSI compilers in iostream
 // but this is also already defined in old GNU compilers
 typedef int streamsize; // oder long ?? MSVC likes int
@@ -52,7 +52,7 @@ typedef int (__stdcall write_callback_type) (void * cb_data, const char* text, i
 typedef int ( write_callback_type) (void * cb_data, const char* text, int length);
 #endif
 //lint !e1712 // no default ctor
-class callbackBuffer : public streambuf {
+class DLLEXPORT callbackBuffer : public streambuf {
 public:
 	callbackBuffer(void * cb_data_p, write_callback_type* wcb) : 
 		cb_data(cb_data_p), write_callback(wcb) {}
@@ -62,7 +62,7 @@ public:
 protected:
     int sync();
     int overflow(int ch);
-	int underflow(void);
+	int underflow();
 
     // Defining xsputn is an optional optimization.
     // (streamsize was recently added to ANSI C++, not portable yet.)
