@@ -32,20 +32,20 @@ class drvCAIRO : public drvbase {
   derivedConstructor(drvCAIRO);
   //(const char * driveroptions_P,ostream & theoutStream,ostream & theerrStream ); // Constructor
   
-  ~drvCAIRO(); // Destructor
+  ~drvCAIRO() override; // Destructor
   class DriverOptions : public ProgramOptions {
   public:
     OptionT < bool, BoolTrueExtractor > pango;
     OptionT < RSString, RSStringValueExtractor > funcname;
     OptionT < RSString, RSStringValueExtractor > header;
     DriverOptions(): 
-      pango(true,"-pango",0,0,"use pango for font rendering",0,false),
+      pango(true,"-pango",nullptr,0,"use pango for font rendering",nullptr,false),
       funcname(true,"-funcname","string",0,
 	       "sets the base name for the generated functions and variables.  e.g. myfig",
-	       0,(const char*)"myfig"),
+	       nullptr,(const char*)"myfig"),
       header(true,"-header","string",0,
 	       "sets the output file name for the generated C header file.  e.g. myfig.h",
-	       0,(const char*)"myfig.h")
+	       nullptr,(const char*)"myfig.h")
       {
 	ADD(pango);
 	ADD(funcname);
@@ -54,13 +54,13 @@ class drvCAIRO : public drvbase {
   }*options;
   
 #include "drvfuncs.h"
-  void show_rectangle(const float llx, const float lly, const float urx, const float ury);
-  void show_text(const TextInfo & textInfo);
-  virtual void ClipPath(cliptype);
+  void show_rectangle(const float llx, const float lly, const float urx, const float ury) override;
+  void show_text(const TextInfo & textinfo) override;
+  void ClipPath(cliptype) override;
   
  public:
   
-  virtual void    show_image(const PSImage & imageinfo); 
+  void    show_image(const PSImage & imageinfo) override; 
   
  private:
   void print_coords();
