@@ -1,9 +1,9 @@
-/* 
+/*
    drvcfdg.cpp : This file is part of pstoedit
    Backend for Context Free Design Grammar files
    Contributed by: Scott Pakin <scott+ps2ed_AT_pakin.org>
 
-   Copyright (C) 1993 - 2014 Wolfgang Glunz, wglunz35_AT_pstoedit.net
+   Copyright (C) 1993 - 2018 Wolfgang Glunz, wglunz35_AT_pstoedit.net
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -31,42 +31,42 @@ drvCFDG::derivedConstructor(drvCFDG): constructBase
 	// Prevent the use of scientific notation, which CFDG doesn't
 	// understand. For now, we hardwire the precision to 6 digits
 	// after the decimal point.
-	outf.setf(ios::fixed); 
+	outf.setf(ios::fixed);
 	outf.precision(6);
- 
-        // Output copyright information
-        outf << "// Converted from PostScript(TM) to CFDG by pstoedit\n"
-             << "// CFDG backend contributed by Scott Pakin <scott+ps2ed_AT_pakin.org>\n"
-             << "// pstoedit is Copyright (C) 1993 - 2014 Wolfgang Glunz"
-             << " <wglunz35_AT_pstoedit.net>\n\n";
 
-        // Output the CFDG startshape
-        outf << "startshape page1\n";
+	// Output copyright information
+	outf << "// Converted from PostScript(TM) to CFDG by pstoedit\n"
+	     << "// CFDG backend contributed by Scott Pakin <scott+ps2ed_AT_pakin.org>\n"
+	     << "// pstoedit is Copyright (C) 1993 - 2014 Wolfgang Glunz"
+	     << " <wglunz35_AT_pstoedit.net>\n\n";
+
+	// Output the CFDG startshape
+	outf << "startshape page1\n";
 }
 
 
 drvCFDG::~drvCFDG()
 {
-        options=0;
+	options=nullptr;
 }
 
 // Each page produces a different path
 void drvCFDG::open_page()
 {
-        outf << "\n"
+	outf << "\n"
 	     << "path page" << currentPageNumber << " {" << endl;
 }
 
 void drvCFDG::close_page()
 {
-        outf << "}" << endl;
+	outf << "}" << endl;
 }
 
 
 // Given an RGB color, output it as an HSV color.
 void drvCFDG::print_rgb_as_hsv(float red, float green, float blue)
 {
-        float hue, saturation, value;
+	float hue, saturation, value;
 	float minchan, maxchan, delta;
 
 	// Determine V (value)
@@ -79,16 +79,16 @@ void drvCFDG::print_rgb_as_hsv(float red, float green, float blue)
 	value = maxchan;
 	delta = maxchan - minchan;
 	if (maxchan == 0.0) {
-	        // Black
-	        outf << "hue 0 sat 0 b 0";
+		// Black
+		outf << "hue 0 sat 0 b 0";
 		return;
 	}
 
 	// Determine S (saturation)
 	saturation = delta / maxchan;
 	if (saturation == 0.0) {
-	        // Gray
-	        outf << "hue 0 sat 0 b " << value;
+		// Gray
+		outf << "hue 0 sat 0 b " << value;
 		return;
 	}
 
@@ -115,34 +115,34 @@ void drvCFDG::print_coords()
 		switch (elem.getType()) {
 		case moveto:{
 				const Point & p = elem.getPoint(0);
-				outf << "  MOVETO {"
-				     << " x " << p.x_ + x_offset
-				     << " y " << p.y_ + y_offset
-				     << " }";
+				outf << "  MOVETO ( "
+				     << p.x_ + x_offset
+				     << ", " << p.y_ + y_offset
+				     << " )";
 			}
 			break;
 		case lineto:{
 				const Point & p = elem.getPoint(0);
-				outf << "  LINETO {"
-				     << " x " << p.x_ + x_offset
-				     << " y " << p.y_ + y_offset
-				     << " }";
+				outf << "  LINETO ( "
+				     << p.x_ + x_offset
+				     << ", " << p.y_ + y_offset
+				     << " )";
 			}
 			break;
 		case closepath:
-		        outf << "  CLOSEPOLY { }";
+			outf << "  CLOSEPOLY ( )";
 			break;
 		case curveto:{
-		        const char* const suffix[] = {"1", "2", ""};
-				outf << "  CURVETO {";
-				for (unsigned int cp = 0; cp < 3; cp++) {
+				outf << "  CURVETO ( ";
+				for (unsigned int i = 0; i < 3; i++) {
+					unsigned int cp = (i + 2) % 3;
 					const Point & p = elem.getPoint(cp);
-					outf << " x" << suffix[cp]
-					     << " " << p.x_ + x_offset
-					     << " y" << suffix[cp]
-					     << " " << p.y_ + y_offset;
+					if (i != 0)
+						outf << ", ";
+					outf << p.x_ + x_offset
+					     << ", " << p.y_ + y_offset;
 				}
-				outf << " }";
+				outf << " )";
 			}
 			break;
 		default:
@@ -156,40 +156,41 @@ void drvCFDG::print_coords()
 
 void drvCFDG::show_path()
 {
-        print_coords();
+	print_coords();
 	switch (currentShowType()) {
 	case drvbase::stroke:
-	        outf << "  STROKE { ";
-		print_rgb_as_hsv(edgeR(), edgeG(), edgeB());
-		outf << " width " << currentLineWidth()
-		     << " param";
+		outf << "  STROKE ( "
+		     << currentLineWidth()
+		     << ", ";
 		switch (currentLineCap()) {
 		case 0:
-		        outf << " buttcap";
+			outf << "CF::ButtCap";
 			break;
 		case 1:
-		        outf << " roundcap";
+			outf << "CF::RoundCap";
 			break;
 		case 2:
-		        outf << " squarecap";
-		        break;
+			outf << "CF::SquareCap";
+			break;
 		default:
-		        // cannot happen
-		        errf << "unexpected LineCap " << (int) currentLineCap();
+			// cannot happen
+			errf << "unexpected LineCap " << (int) currentLineCap();
 			abort();
-		        break;
+			break;
 		}
-		outf << " }";
+		outf << " ) [ ";
+		print_rgb_as_hsv(edgeR(), edgeG(), edgeB());
+		outf << " ]";
 		break;
 	case drvbase::fill:
-	        outf << "  FILL { ";
+		outf << "  FILL [ ";
 		print_rgb_as_hsv(fillR(), fillG(), fillB());
-		outf << " }";
+		outf << " ]";
 		break;
 	case drvbase::eofill:
-	        outf << "  FILL { ";
+		outf << "  FILL ( CF::EvenOdd ) [ ";
 		print_rgb_as_hsv(fillR(), fillG(), fillB());
-		outf << " param evenodd }";
+		outf << " ]";
 		break;
 	default:
 		// cannot happen
@@ -205,7 +206,7 @@ void drvCFDG::show_path()
 
 static DriverDescriptionT < drvCFDG > D_cfdg("cfdg", "Context Free Design Grammar", "Context Free Design Grammar, usable by Context Free Art (http://www.contextfreeart.org/)", "cfdg",
 					     true,	// backend supports subpaths
-					                // if subpathes are supported, the backend must deal with
+							// if subpaths are supported, the backend must deal with
 							// sequences of the following form
 							// moveto (start of subpath)
 							// lineto (a line segment)
@@ -222,5 +223,5 @@ static DriverDescriptionT < drvCFDG > D_cfdg("cfdg", "Context Free Design Gramma
 					     false,	// backend does not support text
 					     DriverDescription::noimage,  // no support for PNG file images
 					     DriverDescription::normalopen, true,	// if format supports multiple pages in one file
-					     false      // backend does not support clipping
+					     false	// backend does not support clipping
 					     );
