@@ -6,7 +6,7 @@
    Class declaration for a sample output driver with no additional attributes
    and methods (minimal interface)
 
-   Copyright (C) 1993 - 2013 Wolfgang Glunz, wglunz35_AT_pstoedit.net
+   Copyright (C) 1993 - 2018 Wolfgang Glunz, wglunz35_AT_pstoedit.net
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -31,19 +31,19 @@ class drvJAVA : public drvbase {
 public:
 
 	derivedConstructor(drvJAVA);
-	~drvJAVA(); // Destructor
+	~drvJAVA() override; // Destructor
 	class DriverOptions : public ProgramOptions { 
 	public:
 		OptionT < RSString, RSStringValueExtractor> jClassName;
 		DriverOptions():
-			jClassName(true,"java class name","string",0,"name of java class to generate",0,(const char *)"PSJava")
+			jClassName(true,"java class name","string",0,"name of java class to generate",nullptr,(const char *)"PSJava")
 		{
 			ADD(jClassName);
 		}
 	}*options;
 
 #include "drvfuncs.h"
-	void show_text(const TextInfo & textInfo);
+	void show_text(const TextInfo & textinfo) override;
 
 private:
 	void print_coords();
