@@ -6,7 +6,7 @@
    Class declaration for a LaTeX2e output driver
    Contributed by: Scott Pakin <scott+ps2ed_AT_pakin.org>
 
-   Copyright (C) 1993 - 2013 Wolfgang Glunz, wglunz35_AT_pstoedit.net
+   Copyright (C) 1993 - 2018 Wolfgang Glunz, wglunz35_AT_pstoedit.net
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -23,15 +23,10 @@
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
 */
-//#ifdef HAVESTL
 #include "drvbase.h"
 
-#ifdef HAVESTL
+#ifdef HAVE_STL
 #include <string>        // C++ string class
-// STL no longer needed, use FontMapper from miscutil.h
-//#include <set>           // C++ STL set class
-//#include <memory>        // Needed for allocator class
-//#include <functional>
 #else
 typedef RSString string;
 #endif
@@ -53,13 +48,13 @@ public:
   derivedConstructor(drvLATEX2E);
   //(const char * driveroptions_P,ostream & theoutStream,ostream & theerrStream ); // Constructor
 
-  ~drvLATEX2E(); // Destructor
+  ~drvLATEX2E() override; // Destructor
 	class DriverOptions : public ProgramOptions { 
 	public:
 		OptionT < bool, BoolTrueExtractor> integersonly;
 
 		DriverOptions():
-			integersonly(true,"-integers","",0,"round all coordinates to the nearest integer",0,false)
+			integersonly(true,"-integers","",0,"round all coordinates to the nearest integer",nullptr,false)
 		{
 			ADD(integersonly);
 		}
@@ -67,8 +62,8 @@ public:
 	}*options;
 
 #include "drvfuncs.h"
-  void show_rectangle(const float llx, const float lly, const float urx, const float ury);
-  void show_text(const TextInfo & textInfo);
+  void show_rectangle(const float llx, const float lly, const float urx, const float ury) override;
+  void show_text(const TextInfo & textinfo) override;
 
 //not supported yet  virtual void show_image(const Image & imageinfo); 
 
@@ -113,7 +108,7 @@ private:
   float prevfontsize;
 };
 
-//#endif // HAVE STL
+//#endif // HAVE_STL
 
 #endif
  
