@@ -33,7 +33,7 @@ public:
 
     derivedConstructor(drvSK);
 
-    ~drvSK();
+    ~drvSK() override;
 	class DriverOptions : public ProgramOptions {
 	public:
 		DriverOptions() 
@@ -42,25 +42,20 @@ public:
 	}*options;
 
 #include "drvfuncs.h"
-	void show_rectangle(const float llx, const float lly, const float urx, const float ury);
-	void show_text(const TextInfo & textInfo);
+	// void show_rectangle(const float llx, const float lly, const float urx, const float ury);
+	void show_text(const TextInfo & textinfo) override;
 
-    virtual void    show_image(const PSImage & imageinfo);
+    void    show_image(const PSImage & imageinfo) override;
 
  protected:
-    virtual bool pathsCanBeMerged(const PathInfo &, const PathInfo &) const;
+    bool pathsCanBeMerged(const PathInfo &, const PathInfo &) const override;
 
  private:
 	void print_coords();
     int id;
-    int getid();
+	int getid() { return id++; }
 
 };
 
-
-inline int drvSK::getid()
-{
-    return id++;
-}
 #endif
  
