@@ -4,7 +4,7 @@
          don't support subpaths
 
    Copyright (C) 1999 Burkhard Plaum plaum_AT_ipf.uni-stuttgart.de
-   Copyright (C) 1999 - 2011  Wolfgang Glunz, wglunz35_AT_pstoedit.net
+   Copyright (C) 1999 - 2018  Wolfgang Glunz, wglunz35_AT_pstoedit.net
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -82,11 +82,11 @@ sub_path::sub_path()
 	num_outside = 0;
 
 	// pointers
-	children = 0;
-	path = 0;
-	points = 0;
-	parents = 0;
-	parent = 0;
+	children = nullptr;
+	path = nullptr;
+	points = nullptr;
+	parents = nullptr;
+	parent = nullptr;
 
 	llx = FLT_MAX;
 	lly = FLT_MAX;
@@ -145,7 +145,7 @@ int sub_path::read(const drvbase::PathInfo & main_path, int start)
 
 	// Count the number of elements is this path
 
-	while (true) {
+	for ( ; ; ) { // while true but without compiler warning
 		if (start + num_elements == main_path.numberOfElementsInPath)
 			break;
 		if (num_elements && (main_path.path[start + num_elements]->getType() == moveto))
@@ -282,7 +282,7 @@ bool sub_path::point_inside(const Point & p) const
 
 		crossings++;
 	}
-	return (crossings & 1) ? true : false;
+	return (crossings & 1);
 }
 
 
@@ -320,7 +320,7 @@ void sub_path_list::find_parents()
 	// Find the parent of each subpath 
 
 	unsigned int i, j;
-	sub_path *parent = 0;
+	sub_path *parent = nullptr;
 
 	// Calculate for each path the number of paths 
 	// outside
@@ -344,7 +344,7 @@ void sub_path_list::find_parents()
 
 	for (i = 0; i < num_paths; i++) {
 		if (!(paths[i].num_outside & 1)) {
-			paths[i].parent = (sub_path *) 0;
+			paths[i].parent = (sub_path *) nullptr;
 			paths[i].children = new sub_path *[num_paths - 1];
 		}
 	}
@@ -383,7 +383,7 @@ void sub_path_list::read(const drvbase::PathInfo & path_info)
 
 	// Count the number of movetos
 
-	for (i = 0; i < path_info.numberOfElementsInPath - 1; i++) {
+	for (i = 0; i < path_info.numberOfElementsInPath - 1; i++) { // ??? why -1 ???
 		if (path_info.path[i]->getType() == moveto)
 			num_paths++;
 	}
@@ -452,23 +452,36 @@ insert_subpath( basedrawingelement **  parent_path,
 
 void drvbase::PathInfo::rearrange()
 {
-	unsigned int test_parent_index= 0, test_child_index = 0;
-	unsigned int parent_index = 0, child_index = 0;
+//	cerr << " numberOfElementsInPath on input " << numberOfElementsInPath << endl;
 	//  write(*this);
 	sub_path_list list;
-	sub_path *child  = (sub_path *) 0;
-	sub_path *parent = (sub_path *) 0;
+	sub_path *child  = (sub_path *) nullptr;
+	sub_path *parent = (sub_path *) nullptr;
 	//  cerr << "Reading subpaths" << endl;
 	list.read(*this);			// Read the list from this
 	//  cerr << "Searching for parents" << endl;
 	list.find_parents();		// Find the parents of all children
 	list.new_points();			// Make the new point arrays
 	list.clean_children();
+	
+#if defined(HAVE_STL) && !defined(USE_FIXED_ARRAY)
+	// temp hack to insert some additional space into the STL vector
+	// which might be needed by the code below - since it doesn't check 
+	// the index anymore.
+	// TBD - fix this.
+	const int additional_space = 4;
+	for (int s = 0; s < additional_space; s++) {
+		addtopath(new Lineto(0.0f,0.0f),cerr);
+		addtopath(new Lineto(0.0f,0.0f),cerr);
+	}
+#endif
+
 	clear();					// Clear the path
 	//  cerr << "Rearranging path" << endl;
 	// Write the elements back
-	unsigned int tmp_num = 0;
-	{for (unsigned int i = 0; i < list.num_paths; i++) {
+	{ 
+	 unsigned int tmp_num = 0;
+ 	 for (unsigned int i = 0; i < list.num_paths; i++) {
 		// Find the next parent
 
 		if (list.paths[i].parent)
@@ -482,12 +495,14 @@ void drvbase::PathInfo::rearrange()
 			// In this loop, we find the closest child and
 			// insert it into the path
 			float min_distance = FLT_MAX;
+			unsigned int parent_index = 0, child_index = 0;
 			for (unsigned int k = 0; k < parent->num_children; k++) {
+				unsigned int test_parent_index= 0, test_child_index = 0;
 				if (parent->children[k]->flags & PS_PATH_IS_CONNECTED)
 					continue;
 				const float test_distance =
 					get_min_distance(&path
-									 [numberOfElementsInPath],
+									 [numberOfElementsInPath], 
 									 parent->children[k]->path,
 									 tmp_num -
 									 numberOfElementsInPath,
@@ -502,17 +517,22 @@ void drvbase::PathInfo::rearrange()
 			}
 //			assert(child != 0 && "fatal error in pstoedit::subpath.cpp::drvbase::PathInfo::rearrange");
 			if (child) {
-				insert_subpath(path, child->path, tmp_num,
+				insert_subpath(&path[0], child->path, tmp_num,
 						   child->num_elements, parent_index + numberOfElementsInPath, child_index);
 				child->flags |= PS_PATH_IS_CONNECTED;
 				tmp_num += child->num_elements + 2;
 			}
 		}}
+#if 0
+		if (tmp_num > numberOfElementsInPath) {
+			cerr << "increasing numberOfElementsInPath from " << numberOfElementsInPath << " to " << tmp_num<< endl;
+		}
+#endif
 		numberOfElementsInPath = tmp_num;
 	} }
 
 	// Remove duplicate linetos
-
+#if 1
 	{for (unsigned int i = 0; i + 1 < numberOfElementsInPath; i++) {
 		if ((path[i]->getType() == lineto)
 			&& (path[i + 1]->getType() == lineto)) {
@@ -520,11 +540,13 @@ void drvbase::PathInfo::rearrange()
 			const Point & pp2 = path[i + 1]->getPoint(0);
 			if ((pp1.x_ == pp2.x_) && (pp1.y_ == pp2.y_)) {
 				delete path[i];
-				for (unsigned int j = i; j + 1 < numberOfElementsInPath; j++)
+				for (unsigned int j = i; j + 1 < numberOfElementsInPath; j++) {
 					path[j] = path[j + 1];
+				}
 				numberOfElementsInPath--;
 			}
 		}
 	}}
+#endif
 	//  write(*this);
 }
